#include "config.h"
#define BUFFER_LEN 200

char input[BUFFER_LEN];

static char* get_key( const char* string )
{
	char*	pt;
	
	strncpy( input, string, sizeof(input) );
	pt = strtok( input , "=" );
	return pt ;
}

static char* get_value( const char* string )
{
	char	*pt = NULL ;

	strncpy( input, string, sizeof(input) );

	pt = strtok( input , "=" );
	pt = strtok( NULL, "=" );
	
	return pt ;
}

struct config_t* load_conf_from_file( const char* file )
{
	FILE* fd ;
	char string[BUFFER_LEN];
	char *key;
	struct config_t* c ;

	if( NULL == file ) {
		fprintf( stderr, "Configuration file error == NULL\n" );
		exit(1);
	}	

	fd = fopen( file, "r+" );
	if( NULL == fd ) {
		fprintf( stderr, "File descriptor is NULL\n" );
		exit(2);
	}

	c = ( struct config_t* )malloc( sizeof(struct config_t) );
	if( NULL == c ) {
		fprintf(stderr, "%s %d >> Malloc\n", __FUNCTION__, __LINE__ );
		exit(3);
	}

	while( fgets( string, sizeof(string) , fd ) ) {

		// newline
		if (string[0]=='\n')
			continue;

		else
			//remove leading /n
			string[ strlen(string) - 1 ] = '\0' ;
		
		// comments
		if (string[0]=='#')
			continue;
	
		// other keys
		
		key=get_key(string);
		
		if( strncmp(key, "host", sizeof(string) ) == 0 ) {
			strncpy( c->host, get_value(string), sizeof(c->host) );
		}
		if( strncmp(key, "user", sizeof(string) ) == 0 ) {
			strncpy( c->user, get_value(string), sizeof(c->user) );
		}
		if( strncmp(key, "password", sizeof(string) ) == 0 ) {
			strncpy( c->password, get_value(string), sizeof(c->password) );
		}
		if( strncmp(key, "remote_file", sizeof(string) ) == 0 ) {
			strncpy( c->remote_file, get_value(string), sizeof(c->remote_file) );
		}
		if( strncmp(key, "enable_ftp", sizeof(string) ) == 0 ) {
			c->enable_ftp=!strncmp(get_value(string),"y",sizeof(string));
		}
		if( strncmp(key, "enable_ftp_monitor", sizeof(string) ) == 0 ) {
			c->enable_ftp_monitor=!strncmp(get_value(string),"y",sizeof(string));
		}
		if( strncmp(key, "dev", sizeof(string) ) == 0 ) {
			strncpy( c->dev, get_value(string), sizeof(c->dev) );
		}
		if( strncmp(key, "ftp_rate", sizeof(string) ) == 0 ) {
			c->ftp_rate=atoi(get_value(string));
		}
		if( strncmp(key, "xres", sizeof(string) ) == 0 ) {
			c->x=atoi(get_value(string));
		}
		if( strncmp(key, "yres", sizeof(string) ) == 0 ) {
			c->y=atoi(get_value(string));
		}
		if( strncmp(key, "bpp", sizeof(string) ) == 0 ) {
			c->bpp=atoi(get_value(string));
		}
		if( strncmp(key, "jpg_quality", sizeof(string) ) == 0 ) {
			c->jpg_quality=atoi(get_value(string));
		}
		if( strncmp(key, "ftp_conn_persistent", sizeof(string) ) == 0 ) {
			if (!strncmp(get_value(string),"auto",sizeof(string)))
				c->ftp_persistent=2;
			else
				c->ftp_persistent=!strncmp(get_value(string),"y",sizeof(string));
		}
	}

	/* update auto ftp_conn_persistent */
	if(c->ftp_persistent==2)
		c->ftp_persistent=(c->ftp_rate<MIN_FTP_PERSISTENT);

	fclose( fd );

	#ifdef DEBUG
	show_conf(c);
	#endif

	return c ;
} 

#ifdef DEBUG

void show_conf( struct config_t* c )
{
	printf("user=%s\n", c->user);
	printf("host=%s\n", c->host);
	printf("password=%s\n", c->password);
	printf("remote_file=%s\n", c->remote_file);
	printf("enable_ftp=%d\n", c->enable_ftp);
	printf("enable_ftp_monitor=%d\n", c->enable_ftp_monitor);
	printf("ftp_conn_persistent=%d\n", c->ftp_persistent);
	printf("dev=%s\n", c->dev);
	printf("ftp_rate=%d\n",c->ftp_rate);
	printf("xres=%d\n",c->x);
	printf("yres=%d\n",c->y);
	printf("bpp=%d\n",c->bpp);
	printf("jpg_quality=%d\n",c->jpg_quality);
}

/*
int main( int argc, char** argv)
{
	struct config_t* c ;

	c = load_conf_from_file( "conf.txt" );	
	show_conf( c );
return 0;
}
*/

#endif
