#include "ftpup.h"
#include "ftplib.h"
#include <stdio.h>

/* connection buffer  */
static netbuf *conn=NULL;

/* FTP: mode (don't touch) */
char mode='I';

int open_conn=0;

/* local functions */
int ftpup_upload(struct config_t *config);
int ftpup(struct config_t *config);
void ftpup_conn(struct config_t *config);

/* upload file */
void ftp_upload(struct config_t *config){
	
	if((!config->ftp_persistent))
		/* upload file and don't mantain connection open */
		ftpup(config);
	else
	{
		/* open FTP connection */
		if(!open_conn)
			ftpup_conn(config);

		/* upload file */
		ftpup_upload(config);
	}
}

void ftpup_conn(struct config_t *config){

	FtpInit();
	
	/* connect to server */
	if(!FtpConnect(config->host,&conn))
	{
		printf("error: connection to FTP server (check ftp address)\n");
		exit(1);
	}

	/* send userid and pw */
	if(!FtpLogin(config->user,config->password,conn))
	{
		printf("error: FTP auth failed (check login and password)\n");
		exit(2);
	}
	
	/* connection open */
	open_conn=1;
}

int ftpup(struct config_t *config){

	/* open connection */
	ftpup_conn(config);

	/* upload file */
	ftpup_upload(config);	

	/* disconnect */	
	ftpup_close();

	return(0);
}

int ftpup_upload(struct config_t *config){

	/* upload file (tmp name) */
	if(!FtpPut(config->local_file,config->remote_tmp_file,mode,conn))
	{
		printf("%s, %s, %c", config->local_file, config->remote_tmp_file,mode);
		printf("error: upload tmp remote file\n");
		return(3);
	}

	/* delete remote file  */
	/*
	if(!FtpDelete(file_remoto,conn))
	{
		printf("error: delete remote file");
		return(4);
	}
	*/
	
	/* rename tmp file */
	if(!FtpRename(config->remote_tmp_file, config->remote_file,conn))
	{
		printf("error: renaming remote tmp file");
		return(5);
	}
	return(0);
}

void ftpup_close(){
	
	/* disconnect */
	if (open_conn){
		FtpQuit(conn);
		open_conn=0;
	}
}
